<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ru">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="26"/>
        <location filename="ui_mainwindow.h" line="756"/>
        <source>Network Assistant</source>
        <translation>Помощник настройки сети</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="86"/>
        <location filename="ui_mainwindow.h" line="799"/>
        <source>About...</source>
        <translation>О программе...</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="109"/>
        <location filename="ui_mainwindow.h" line="803"/>
        <source>Help</source>
        <translation>Справка</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="177"/>
        <location filename="ui_mainwindow.h" line="805"/>
        <source>&amp;Close</source>
        <translation>&amp;Закрыть</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="184"/>
        <location filename="ui_mainwindow.h" line="807"/>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="219"/>
        <location filename="ui_mainwindow.h" line="770"/>
        <source>Status</source>
        <translation>Статус</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="225"/>
        <location filename="ui_mainwindow.h" line="757"/>
        <source>IP address</source>
        <translation>IP-адрес</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="261"/>
        <location filename="ui_mainwindow.h" line="760"/>
        <source>Hardware detected</source>
        <translation>Оборудование обнаружено</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="280"/>
        <source>Enable</source>
        <translation>Включить</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="303"/>
        <location filename="mainwindow.ui" line="593"/>
        <location filename="mainwindow.ui" line="706"/>
        <location filename="ui_mainwindow.h" line="761"/>
        <location filename="ui_mainwindow.h" line="774"/>
        <location filename="ui_mainwindow.h" line="780"/>
        <source>Re-scan</source>
        <translation>Повторить сканирование</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="372"/>
        <source>Enabled</source>
        <translation>Включено</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="377"/>
        <source>Interface</source>
        <translation>Интерфейс</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="382"/>
        <source>Driver</source>
        <translation>Драйвер</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="387"/>
        <source>Description</source>
        <translation>Описание</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="392"/>
        <source>Vendor</source>
        <translation>Производитель</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="397"/>
        <source>Product</source>
        <translation>Продукт</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="405"/>
        <source>Disable</source>
        <translation>Отключить</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="419"/>
        <location filename="ui_mainwindow.h" line="762"/>
        <source>Active interface</source>
        <translation>Активный интерфейс</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="435"/>
        <location filename="ui_mainwindow.h" line="764"/>
        <source>WiFi status</source>
        <translation>Статус WiFi</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="457"/>
        <location filename="ui_mainwindow.h" line="767"/>
        <source>Unblocks all soft/hard blocked wireless devices</source>
        <translation>Разблокирует все программно/аппаратно заблокированные беспроводные устройства</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="460"/>
        <location filename="ui_mainwindow.h" line="769"/>
        <source>Unblock WiFi Devices</source>
        <translation>Разблокировать устройства WiFi</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="492"/>
        <location filename="ui_mainwindow.h" line="776"/>
        <source>Linux drivers</source>
        <translation>Linux драйверы</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="504"/>
        <location filename="ui_mainwindow.h" line="771"/>
        <source>Associated Linux drivers</source>
        <translation>Ассоциированные Linux драйверы</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="513"/>
        <location filename="ui_mainwindow.h" line="772"/>
        <source>Load Driver</source>
        <translation>Загрузить драйвер</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="576"/>
        <location filename="ui_mainwindow.h" line="773"/>
        <source>Unload Driver</source>
        <translation>Выгрузить драйвер</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="613"/>
        <location filename="mainwindow.cpp" line="833"/>
        <location filename="ui_mainwindow.h" line="775"/>
        <source>Block Driver</source>
        <translation>Заблокировать драйвер</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="632"/>
        <location filename="ui_mainwindow.h" line="785"/>
        <source>Windows drivers</source>
        <translation>Windows драйверы</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="638"/>
        <location filename="ui_mainwindow.h" line="777"/>
        <source>Available Windows drivers</source>
        <translation>Доступные драйвера под Windows</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="672"/>
        <location filename="ui_mainwindow.h" line="778"/>
        <source>Remove Driver</source>
        <translation>Удалить драйвер</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="683"/>
        <location filename="ui_mainwindow.h" line="779"/>
        <source>Add Driver</source>
        <translation>Добавить драйвер</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="724"/>
        <location filename="ui_mainwindow.h" line="781"/>
        <source>About NDISwrapper</source>
        <translation>О программе NDISwrapper</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="736"/>
        <location filename="ui_mainwindow.h" line="782"/>
        <source>Install NDISwrapper</source>
        <translation>Установить NDISwrapper</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="747"/>
        <location filename="ui_mainwindow.h" line="783"/>
        <source>In order to use Windows drivers you need first to install NDISwrapper</source>
        <translation>Для использования драйверов под Windows необходимо сначала установить NDISwrapper</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="763"/>
        <location filename="ui_mainwindow.h" line="784"/>
        <source>Uninstall NDISwrapper</source>
        <translation>Удалить NDISwrapper</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="795"/>
        <location filename="ui_mainwindow.h" line="798"/>
        <source>Net diagnostics</source>
        <translation>Диагностика сети</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="807"/>
        <location filename="ui_mainwindow.h" line="786"/>
        <source>Ping</source>
        <translation>Пинг</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="813"/>
        <location filename="mainwindow.ui" line="933"/>
        <location filename="ui_mainwindow.h" line="787"/>
        <location filename="ui_mainwindow.h" line="793"/>
        <source>Target URL:</source>
        <translation>URL назначения:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="823"/>
        <location filename="ui_mainwindow.h" line="788"/>
        <source>Packets</source>
        <translation>Пакеты</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="868"/>
        <location filename="mainwindow.ui" line="991"/>
        <location filename="ui_mainwindow.h" line="789"/>
        <location filename="ui_mainwindow.h" line="795"/>
        <source>Start</source>
        <translation>Старт</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="885"/>
        <location filename="mainwindow.ui" line="1008"/>
        <location filename="ui_mainwindow.h" line="790"/>
        <location filename="ui_mainwindow.h" line="796"/>
        <source>Clear</source>
        <translation>Очистить</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="899"/>
        <location filename="mainwindow.ui" line="1022"/>
        <location filename="ui_mainwindow.h" line="791"/>
        <location filename="ui_mainwindow.h" line="797"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="927"/>
        <location filename="ui_mainwindow.h" line="792"/>
        <source>Traceroute</source>
        <translation>Трассировка</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="943"/>
        <location filename="ui_mainwindow.h" line="794"/>
        <source>Hops</source>
        <translation>Прыжки</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="86"/>
        <source>IP address from router:</source>
        <translation>IP-адрес от маршрутизатора:</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="87"/>
        <source>External IP address:</source>
        <translation>Внешний IP=адрес:</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="124"/>
        <location filename="mainwindow.cpp" line="137"/>
        <source>Interface: %1</source>
        <translation>Интерфейс: %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="124"/>
        <location filename="mainwindow.cpp" line="138"/>
        <source>Driver: %1</source>
        <translation>Драйвер: %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="125"/>
        <location filename="mainwindow.cpp" line="139"/>
        <source>Description: %1</source>
        <translation>Описание: %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="126"/>
        <location filename="mainwindow.cpp" line="140"/>
        <source>Product: %1</source>
        <translation>Продукт: %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="126"/>
        <location filename="mainwindow.cpp" line="141"/>
        <source>Vendor: %1</source>
        <translation>Производитель: %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="127"/>
        <location filename="mainwindow.cpp" line="142"/>
        <source>Enabled: %1</source>
        <translation>Включено: %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="195"/>
        <location filename="mainwindow.cpp" line="209"/>
        <location filename="mainwindow.cpp" line="223"/>
        <source>&amp;Copy</source>
        <translation>&amp;Копировать</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="197"/>
        <location filename="mainwindow.cpp" line="211"/>
        <location filename="mainwindow.cpp" line="225"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="198"/>
        <location filename="mainwindow.cpp" line="212"/>
        <location filename="mainwindow.cpp" line="226"/>
        <source>Copy &amp;All</source>
        <translation>Копировать &amp;Все</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="200"/>
        <location filename="mainwindow.cpp" line="214"/>
        <location filename="mainwindow.cpp" line="228"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="260"/>
        <location filename="mainwindow.cpp" line="277"/>
        <source>Traceroute not installed</source>
        <translation>Программа traceroute не установлена</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="261"/>
        <source>Traceroute is not installed, do you want to install it now?</source>
        <translation>Программа traceroute не установлена, вы хотите установить ее сейчас?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="267"/>
        <source>Traceroute hasn&apos;t been installed</source>
        <translation>Программа traceroute не была установлена</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="268"/>
        <source>Traceroute cannot be installed. This may mean you are using the LiveCD or you are unable to reach the software repository,</source>
        <translation>Программа traceroute не может быть установлена. Возможно, Вы используете LiveCD, или Вам не удалось подключиться к репозиторию.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="278"/>
        <source>Traceroute is not installed and no Internet connection could be detected so it cannot be installed</source>
        <translation>Программа traceroute не установлена, и не обнаружено подключение к Интернету, поэтому она не может быть установлена</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="285"/>
        <location filename="mainwindow.cpp" line="330"/>
        <source>No destination host</source>
        <translation>Нет компьютера назначения</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="285"/>
        <location filename="mainwindow.cpp" line="330"/>
        <source>Please fill in the destination host field</source>
        <translation>Пожалуйста, заполните поле компьютера назначения</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="445"/>
        <source>Loaded Drivers</source>
        <translation>Загруженные драйвера</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="454"/>
        <source>Unloaded Drivers</source>
        <translation>Выгруженные драйвера</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="468"/>
        <source>Blocked Drivers</source>
        <translation>Заблокированные драйвера</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="488"/>
        <source>Blocked Broadcom Drivers</source>
        <translation>Заблокированные драйвера Broadcom</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="510"/>
        <source>Ndiswrapper is not installed</source>
        <translation>Ndiswrapper не установлена</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="523"/>
        <source>driver installed</source>
        <translation>драйвер установлен</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="532"/>
        <source> and in use by </source>
        <translation>и используется</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="539"/>
        <source>. Alternate driver: </source>
        <translation>. Альтернативный драйвер:</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="603"/>
        <source>Driver removed from blocklist</source>
        <translation>Драйвер извлечен из блокировки</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="603"/>
        <source>Driver removed from blocklist.</source>
        <translation>Драйвер извлечен из блокировки.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="609"/>
        <source>Module blocked</source>
        <translation>Модуль заблокирован</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="763"/>
        <source>Installation successful</source>
        <translation>Установка завершилась успешно</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="765"/>
        <source>Error detected, could not compile ndiswrapper driver.</source>
        <translation>Обнаружена ошибка, невозможно скомпилировать драйвер NdisWrapper.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="768"/>
        <source>Error detected, could not install ndiswrapper.</source>
        <translation>Обнаружена ошибка, невозможно установить драйвер NdisWrapper.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="780"/>
        <source>Error encountered while removing Ndiswrapper</source>
        <translation>Ошибка при удалении Ndiswrapper</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="830"/>
        <source>Unblock Driver</source>
        <translation>Разблокировать драйвер</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="862"/>
        <source>enabled</source>
        <translation>активирован</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="865"/>
        <source>disabled</source>
        <translation>отключен</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="868"/>
        <source>WiFi hardware switch is off</source>
        <translation>WiFi отключен аппаратным переключателем</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="875"/>
        <source>Locate the Windows driver you want to add</source>
        <translation>Найдите Windows драйвер, который Вы хотите добавить</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="876"/>
        <source>Windows installation information file (*.inf)</source>
        <translation>Файл установочной информации Windows (*.inf)</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="907"/>
        <source>*.sys file not found</source>
        <translation>*.sys файл не найден</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="908"/>
        <source>The *.sys files must be in the same location as the *.inf file. %1 cannot be found</source>
        <translation>Файл *.sys должен быть в том же местоположении, что и *.inf файл. %1 не может быть найден</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="919"/>
        <source>sys file reference not found</source>
        <translation>Ссылка на sys файл не найдена</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="920"/>
        <source>The sys file for the given driver cannot be determined after parsing the inf file</source>
        <translation>Файл sys для этого драйвера не может быть определен после анализа inf файла</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="937"/>
        <source>Ndiswrapper driver removed.</source>
        <translation>Ndiswrapper драйвер удален.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="945"/>
        <source>%1 Help</source>
        <translation>%1 Справка</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="957"/>
        <source>Could not unlock devices.
WiFi device(s) might already be unlocked.</source>
        <translation>Не удалось разблокировать устройства.
Wi-Fi устройство(а) может быть уже разблокировано.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="959"/>
        <source>WiFi devices unlocked.</source>
        <translation>WiFi устройства разблокированы.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="974"/>
        <source>About %1</source>
        <translation>О %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="975"/>
        <source>Version: </source>
        <translation>Версия: </translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="976"/>
        <source>Program for troubleshooting and configuring network for antiX Linux</source>
        <translation>Программа для устранения неполадок и настройки сети для antiX Linux</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="978"/>
        <source>Copyright (c) MEPIS LLC and MX Linux</source>
        <translation>Авторское право (c) MEPIS LLC и MX Linux</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="979"/>
        <source>%1 License</source>
        <translation>%1 Лицензия</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1005"/>
        <source>Driver loaded successfully</source>
        <translation>Драйвер загружен успешно</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1020"/>
        <source>Driver unloaded successfully</source>
        <translation>Драйвер выгружен успешно</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="about.cpp" line="52"/>
        <source>License</source>
        <translation>Лицензия</translation>
    </message>
    <message>
        <location filename="about.cpp" line="53"/>
        <location filename="about.cpp" line="63"/>
        <source>Changelog</source>
        <translation>Список изменений</translation>
    </message>
    <message>
        <location filename="about.cpp" line="54"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="about.cpp" line="76"/>
        <source>&amp;Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <location filename="main.cpp" line="70"/>
        <location filename="main.cpp" line="78"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="main.cpp" line="71"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Программа запущена суперпользователем. Для использования программы войдите в систему как обычный пользователь.</translation>
    </message>
    <message>
        <location filename="main.cpp" line="79"/>
        <source>You must run this program with admin access.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="624"/>
        <source>Could not load </source>
        <translation>Невозможно загрузить</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="649"/>
        <source>Could not unload </source>
        <translation>Невозможно выгрузить</translation>
    </message>
</context>
</TS>